@@ -602,15 +602,9 @@ sub embed_css_unbundled
 {
     load_devel_dependencies();
     foreach my $css (@theme_bundle_css) {
-        my $ext = '.src.css';
-        if ($css =~ /\[scss\]$/) {
-            $ext = '.src.scss.css';
-            $css =~ s/\[scss\]$//;
-        }
-        printf " <link type='text/css' href=\"%s/unauthenticated/css/%s%s?%s\" rel=\"stylesheet\">\n",
+        printf " <link type='text/css' href=\"%s/unauthenticated/css/%s.src.css?%s\" rel=\"stylesheet\">\n",
                $theme_webprefix,
                $css,
-               $ext,
                theme_version('timestamped');
     }
     embed_css_fonts();
@@ -1772,7 +1766,7 @@ sub theme_night_mode_login_auto
 {
     if ($theme_config{'settings_global_palette_unauthenticated'} eq 'auto') {
         my $detect;
-        $detect = '<script type="application/javascript">';
+        $detect = '<script type="application/javascript">console.log("Auto dark mode");';
         $detect .= 'if (window.matchMedia && window.matchMedia("(prefers-color-scheme: dark)").matches) {';
         $detect .= 'document.querySelector("html").setAttribute("data-bgs", "nightRider")';
         $detect .= '} else {';
